@@ -1,15 +1,19 @@
+import logging
+
 from re import fullmatch
 
 from django.utils.translation import activate
 from django.http import HttpResponseBadRequest
 
+logger = logging.getLogger()
+
 
 class LocaleMiddleware(object):
     def __init__(self, get_response):
         self.get_response = get_response
 
     def __call__(self, request):
-
+        logger.info(request.headers)
         accept_language = request.META.get('HTTP_ACCEPT_LANGUAGE')
         if not accept_language:
             return HttpResponseBadRequest(
@@ -21,7 +25,7 @@ class LocaleMiddleware(object):
             )
 
         activate(accept_language)
-        
+
         request.locale = accept_language
 
         response = self.get_response(request)
